@@ -3,10 +3,21 @@ json rpc helper
 """
 
 import socket
+from dataclasses import dataclass, field
 from json import dumps, loads
+from typing import Dict
 from uuid import uuid4
 
-from sanic.log import logger
+from sanic import Sanic
+
+
+@dataclass
+class EmptyApp:
+    """
+    empty dummy app in case sanic is unavailable
+    """
+
+    config: Dict = field(default_factory=dict)
 
 
 def jsonrpc(data: dict, host: str = "localhost", port: int = 7583):
@@ -16,6 +27,12 @@ def jsonrpc(data: dict, host: str = "localhost", port: int = 7583):
     request_id = str(uuid4())
     data.update({"jsonrpc": "2.0", "id": request_id})
     recv_buffer = []
+    try:
+        app = Sanic.get_app()
+    except Exception:  # pylint: disable=broad-except
+        app = EmptyApp()
+    host = app.config.get("JSONRPC_HOST", host)
+    port = app.config.get("JSONRPC_PORT", port)
     sock_type = socket.AF_INET
     sock_conn = (host, port)
     if host.startswith("unix://"):
@@ -35,7 +52,8 @@ def jsonrpc(data: dict, host: str = "localhost", port: int = 7583):
                     recv_buffer = []
                     if res.get("id") == request_id:
                         return res
-        except Exception as err:
+        except Exception as err:  # pylint: disable=broad-except
             error = getattr(err, "message", repr(err))
-            logger.error(error)
-            raise
+            raise RuntimeError(
+                f"Unable to connect to signal-cli JSON RPC: {error}"
+            ) from err
